@@ -62,7 +62,7 @@ gboolean devilspie2_emulate=FALSE;
 lua_State *
 init_script()
 {
-	lua_State *lua=lua_open();
+	lua_State *lua=luaL_newstate();
 	luaL_openlibs(lua);
 
 	register_cfunctions(lua);
@@ -111,6 +111,7 @@ register_cfunctions(lua_State *lua)
 
 	lua_register(lua,"set_window_workspace",c_set_window_workspace);
 	lua_register(lua,"change_workspace",c_change_workspace);
+	lua_register(lua,"get_workspace_count",c_get_workspace_count);
 
 	lua_register(lua,"pin_window",c_pin_window);
 	lua_register(lua,"unpin_window",c_unpin_window);
